@@ -22,6 +22,7 @@ from airflow.hooks.base import BaseHook
 from airflow.providers.postgres.hooks.postgres import PostgresHook
 from airflow.providers.snowflake.hooks.snowflake import SnowflakeHook
 
+from astro.constants import DEFAULT_CHUNK_SIZE
 from astro.sql.table import Table, TempTable, create_table_name
 from astro.utils.load_dataframe import move_dataframe_to_sql
 from astro.utils.schema_util import get_schema
@@ -108,6 +109,7 @@ class SqlDataframeOperator(DecoratedOperator):
                 df=ret,
                 conn_type=conn.conn_type,
                 user=conn.login,
+                chunksize=DEFAULT_CHUNK_SIZE,
             )
             return self.output_table
         else:
@@ -138,9 +140,13 @@ class SqlDataframeOperator(DecoratedOperator):
             self.hook = PostgresHook(
                 postgres_conn_id=table.conn_id, schema=table.database
             )
+            schema = table.schema or get_schema()
             query = (
-                sql.SQL("SELECT * FROM {input_table}")
-                .format(input_table=sql.Identifier(table.table_name))
+                sql.SQL("SELECT * FROM {schema}.{input_table}")
+                .format(
+                    schema=sql.Identifier(schema),
+                    input_table=sql.Identifier(table.table_name),
+                )
                 .as_string(self.hook.get_conn())
             )
             return self.hook.get_pandas_df(query)
